# Description

This repository contains the code to simulate a neuronal network in the honeybee primary auditory center.

This model has been added to ModelDB ([Accession number 239413](https://senselab.med.yale.edu/ModelDB/showmodel.cshtml?model=239413#tabs-1))

This repo contains parts of the code written by Aynur Maksutov during AMGEN program 2016 at Wachtlerlab, LMU, Munich.

## Author
Ajayrama Kumaraswamy, ajayramak@bio.lmu.de

## References

### Experimental context and brief summary
>Ai, H., Kai, K., Kumaraswamy, A., Ikeno, H., & Wachtler, T. (2017). Interneurons in the honeybee primary auditory center responding to waggle dance-like vibration pulses. *The Journal of Neuroscience*. https://doi.org/10.1523/JNEUROSCI.0044-17.2017

### Detailed description of model and simulations
>Kumaraswamy, A., Maksutov, A., Kai, K., Ai, H., Ikeno, H., & Wachtler, T. (2017). Network simulations of interneuron circuits in the honeybee primary auditory center. *bioRxiv*. https://doi.org/10.1101/159533



 
# Installation
## With anaconda (recommended):

Step 1: Download the repository
 

Step 2: Create a new virtual environment and install some dependencies

`conda create --name Ai2017Sim -c brian-team ipython>=6.1 numpy>=1.11.2 matplotlib>=1.5.3 seaborn>=0.7.1 brian2>=2.0.1 python>=3.5`

Step 3: Activate the virtual environment

`source activate Ai2017Sim` (unix) or `activate Ai2017Sim` (windows)


Step 4: Install the package (the option '-e' is required)

`pip install -e <full path of this repository>`


## Without anaconda (normal python installation required, https://www.python.org/)

Step 1: Download the repository 

Step 2: Install virtualenvwrapper (unix) or virtualenvwrapper-win (windows) with pip

Step 3: (only on windows) Install microsoft Visual C++ 14.0. Get it with "Microsoft Visual C++ Build Tools" [here](http://landinghub.visualstudio.com/visual-cpp-build-tools)

Step 4: Create virtual environment

`mkvirtualenv Ai2017Sim`


Step 5: Install the package (the option '-e' is required)

`pip install -e <full path of this repository>`

# Usage:
Step 1: Activate the virtual environment

`source activate Ai2017Sim` (unix) or `activate Ai2017Sim` (windows)

Step 2: Change the variable 'homeFolder' in the file 'dirDefs.py' to a folder of your choice. The results of the simulation will be stored here.

Step 3: The scripts of this repository are described below. All of them have some parameters at their top. Change these and run the scripts as needed.


# Overview of Contents

* **HB-PAC_disinhibitory_network** 
  * **Ai2017Sim.yml:** A file that can be used to create a conda environment to run the scripts below. Essentially is a list of dependencies.
  
  * **models**
   
     * **neuronModels.py:** wrapper classes for brian2 neuron models
     * **neurons.py:** Model equations and static parameters for neurons  
     * **synapses.py:** Model equations for synapses  
  
  * **paramLists**  
    
     * **AdExpPars.py:** Parameter combinations for the AdExp model  
     * **inputParsList.py:** Stimulii definitions  
     * **synapsePropsList.py:** Parameter combinations for the difference of exponential synaptic conductance model  
     
  * **brianUtils.py:** utility functions related to brian2  
  
  * **dirDefs.py:** directory definitions imported in other scripts  
  
  * **DLInt1SynCurrent.py:** Script to simulate DL-Int-1 recording membrane potential and synaptic currents in [NIX](https://github.com/G-Node/nixpy) files    
  
  * **DLInt2try.py:** Legacy code  
  
  * **forAi2017.py:** Script to generate a subplot of an upcoming manuscript.  
  
  * **JODLInt1DLInt2:** Class to run network simulations  
  
  * **justDLInt1.py:** Legacy code  
  
  * **mplPars.py:** matplotlib rc parameters  
  
  * **neoNIXIO.py:** adapted from [GJEphys](https://github.com/wachtlerlab/GJEphys), utility functions to work jointly with [NIX](https://github.com/G-Node/nixpy) and [neo](https://github.com/NeuralEnsemble/python-neo).  
  
  * **plotDLInt1DLInt2SynEffects.py:** script to plot summary of DL-Int-1 and DL-Int-2 responses to pulse trains.  
  
  * **plotShortStims.py:** script to plot summary of DL-Int-1 and DL-Int-2 responses to short continuous pulses.  
  
  * **plotSynCurrents.py:** script to plot membrane potential and synaptic currents of DL-Int-1 and DL-Int-2 for one stimulus.  
  
  * **runJODLInt1DLInt2Multiple.py:** script to simulate the network for multiple stimulii. Output is saved as a [NIX](https://github.com/G-Node/nixpy) File.  
  
  * **simSynCurrents.py:** script to simulate DL-Int-1 and DL-Int-2 recording membrane potential and synaptics currents in a [NIX](https://github.com/G-Node/nixpy) file.  

